unit CGIDlg;

interface

uses
  SysUtils,
  WinTypes,
  WinProcs,
  Messages,
  Classes,
  Graphics,
  Controls,
  Forms,
  Dialogs,
  Menus,
  StdCtrls,
  ExtCtrls,
  Grids,
  TabNotBk,
  CGI, Buttons, ComCtrls;

type
  TCGIDebugDlg = class(TForm)
    ButtonPanel: TPanel;
    InfoNotebook: TTabbedNotebook;
    BitBtn1: TBitBtn;
    LCGIParams: TStringGrid;
    LFormTuples: TStringGrid;
    LClientServer: TStringGrid;
    LExtraHeaders: TStringGrid;
  private
	 { Private declarations }
  public
	 { Public declarations }
  end;

	TCGIDlg = class(TComponent)
	private
		FCGI: TCGI;
		procedure SetCGI(Value: TCGI);
    procedure Notification(AComponent: TComponent; Operation: TOperation); override;
	public
		constructor Create(AOwner: TComponent); override;
    procedure Execute;
	published
		property CGI: TCGI read FCGI write SetCGI;
	end;

implementation

{$R *.DFM}

constructor TCGIDlg.Create(AOwner: TComponent);
begin
	inherited Create(AOwner);
end;

procedure TCGIDlg.Execute;
var
	CGIDebugDlg: TCGIDebugDlg;
	SDebug: String;
   POutput: PChar;

	 procedure AddPair(Grid: TStringGrid; Col1, Col2: string);
	 begin
			with Grid do begin
				RowCount := RowCount + 1;
				Cells[0,RowCount-1] := Col1;
				Cells[1,RowCount-1] := Col2;
			end;
	 end;

	 procedure ShowPairs(Grid: TStringGrid; List: TStringList);
	 var
			i: integer;
	 begin
			with List do begin
				for i := 0 to Count - 1 do begin
					AddPair(Grid,Names[i],Values[Names[i]]);
				end;
			end;
	 end;

begin
	if FCGI = nil then exit;
	CGIDebugDlg := TCGIDebugDlg.Create(Self);
	with FCGI, CGIDebugDlg do begin
		with Profile do begin
			if DebugMode then SDebug := 'Yes' else SDebug := 'No';

			with LCGIParams do begin
				Cells[0,0] := 'Parameter';
				Cells[1,0] := 'Value';
				RowCount := 1;
			end;
			AddPair(LCGIParams,'Debug Mode',SDebug);
      AddPair(LCGIParams,'Profile File',ProfileFile);
			AddPair(LCGIParams,'Content File',ContentFile);
			AddPair(LCGIParams,'Output File',OutputFile);
      AddPair(LCGIParams,'GMT Offset',IntToStr(GMTOffset));
			AddPair(LCGIParams,' ',' ');
			AddPair(LCGIParams,'CGI Version',Version);
			AddPair(LCGIParams,'Request Protocol',RequestProtocol);
			AddPair(LCGIParams,'Request Method',RequestMethod);
			AddPair(LCGIParams,'Query String',QueryString);
			AddPair(LCGIParams,'Content Type',ContentType);
			AddPair(LCGIParams,'Content Length',IntToStr(ContentLength));
			AddPair(LCGIParams,' ',' ');
			AddPair(LCGIParams,'Executable Path',ExecutablePath);
			AddPair(LCGIParams,'Physical Path',PhysicalPath);
			AddPair(LCGIParams,'Logical Path',LogicalPath);
			LCGIParams.FixedRows := 1;

			with LClientServer do begin
				Cells[0,0] := 'Parameter';
				Cells[1,0] := 'Value';
				RowCount := 1;
			end;
			AddPair(LClientServer,'Server Software',ServerSoftware);
			AddPair(LClientServer,'Server Name',ServerName);
			AddPair(LClientServer,'Server Administrator',ServerAdmin);
			AddPair(LClientServer,'Server Port',IntToStr(ServerPort));
			AddPair(LClientServer,' ',' ');
			AddPair(LClientServer,'Remote Host',RemoteHost);
			AddPair(LClientServer,'Remote Address',RemoteAddr);
			AddPair(LClientServer,'Authorized Username',AuthUser);
			AddPair(LClientServer,'Authentication Method',AuthType);
			AddPair(LClientServer,'RFC-931 Identity',TAPUser);
			LClientServer.FixedRows := 1;

			ShowPairs(LExtraHeaders,ExtraHeaders);
			with LExtraHeaders do begin
				if RowCount = 1 then RowCount := 2;
				FixedRows := 1;
			end;
		end;

		ShowPairs(LFormTuples,FormFields);
		with LFormTuples do begin
			if RowCount = 1 then RowCount := 2;
			FixedRows := 1;
		end;

		CGIDebugDlg.ShowModal;
	end;
end;

procedure TCGIDlg.SetCGI(Value: TCGI);
begin
	if FCGI <> Value then FCGI := Value;
end;

procedure TCGIDlg.Notification(AComponent: TComponent; Operation: TOperation);
begin
	inherited Notification(AComponent, Operation);
   if (Operation = opRemove) and (AComponent = FCGI) then
   	FCGI := nil;
end;

end.
